# Ingredients with Links

---

- [link to something](./another_recipe.md)

- [link to something else](http://example.org)

- *5 ml* [link to something with amount](http://example.org)

- [link with spaces in target](<./foo bar.md>)

- [link with title that is ignored](<./foo.md> "This is allowed but not represented in the parse result")

- [not parsed as a link](http://example.org) due to additional text after it

- [not parsed as a link](http://example.org) 
  
  due to second paragraph